
function initializeCarousel() {
    const track = document.querySelector('.carousel-track');
    const slides = Array.from(track.children);
    const nextButton = document.querySelector('.carousel-button.right');
    const prevButton = document.querySelector('.carousel-button.left');

    if (!track || slides.length === 0 || !nextButton || !prevButton) return;

    let slideWidth = slides[0].getBoundingClientRect().width || 0;
    let currentIndex = 0;

    // Arrange slides in a row
    slides.forEach((slide, index) => {
        slide.style.left = `${slideWidth * index}px`;
    });

    function moveToSlide(index) {
        if (slides.length > 0) {
            track.style.transform = `translateX(-${index * slideWidth}px)`;
            currentIndex = index;
        }
    }

    nextButton.addEventListener('click', () => {
        if (currentIndex < slides.length - 1) {
            moveToSlide(currentIndex + 1);
        }
    });

    prevButton.addEventListener('click', () => {
        if (currentIndex > 0) {
            moveToSlide(currentIndex - 1);
        }
    });

    // Responsive Resize Fix
    window.addEventListener('resize', () => {
        slideWidth = slides[0].getBoundingClientRect().width || 0;
        moveToSlide(currentIndex);
    });
}
// Initialize the carousel after DOM is loaded
document.addEventListener("DOMContentLoaded", initializeCarousel);





function initializeModal() {
    const modal = document.getElementById('modal');
    const modalImg = document.getElementById('modal-image');
    const images = document.querySelectorAll('.gallery_image');
    const closeModalBtn = document.getElementById('close-modal');
    const nextBtn = document.getElementById('next');
    const prevBtn = document.getElementById('prev');

    if (!modal || !modalImg || images.length === 0) return;

    let modalIndex = 0;

    function openModal(index) {
        modal.style.display = 'flex';
        modalImg.src = images[index].src;
        modalIndex = index;
    }

    function closeModal() {
        modal.style.display = 'none';
    }

    function nextImage() {
        modalIndex = (modalIndex + 1) % images.length;
        modalImg.src = images[modalIndex].src;
    }

    function prevImage() {
        modalIndex = (modalIndex - 1 + images.length) % images.length;
        modalImg.src = images[modalIndex].src;
    }

    images.forEach((img, index) => {
        img.addEventListener('click', () => openModal(index));
    });

    closeModalBtn?.addEventListener('click', closeModal);
    nextBtn?.addEventListener('click', nextImage);
    prevBtn?.addEventListener('click', prevImage);

    modal.addEventListener('click', (e) => {
        if (e.target === modal) closeModal();
    });
}

// Initialize modal functionality after DOM is loaded
document.addEventListener("DOMContentLoaded", initializeModal);






// Form Submission
document.getElementById('contactForm')?.addEventListener('submit', function (e) {
    e.preventDefault();
    const name = document.getElementById('name').value;
    const responseMessage = document.getElementById('responseMessage');
    responseMessage.textContent = `Thank you, ${name}! Your message has been sent.`;
    this.reset();
});




function initializeFacultySlider() {
    const track = document.querySelector('.faculty-slider-track');
    const slides = Array.from(track.children);
    const nextButton = document.getElementById('faculty-next');
    const prevButton = document.getElementById('faculty-prev');

    if (!track || slides.length === 0 || !nextButton || !prevButton) return;

    let currentIndex = 0;
    const visibleItems = 3; // Show 3 items at a time
    let slideWidth = slides[0].getBoundingClientRect().width + 15; // Card width + gap

    function updateCarousel() {
        track.style.transform = `translateX(-${currentIndex * slideWidth}px)`;
    }

    nextButton.addEventListener('click', () => {
        if (currentIndex < slides.length - visibleItems) {
            currentIndex++;
            updateCarousel();
        }
    });

    prevButton.addEventListener('click', () => {
        if (currentIndex > 0) {
            currentIndex--;
            updateCarousel();
        }
    });

    // Responsive Fix (Recalculate on Resize)
    window.addEventListener('resize', () => {
        slideWidth = slides[0].getBoundingClientRect().width + 15;
        updateCarousel();
    });
}

// Initialize slider
document.addEventListener("DOMContentLoaded", initializeFacultySlider);
